@@ -13,7 +13,7 @@ import numpy as np
 import tqdm
 
 
-__version__ = '0.10.0'
+__version__ = '0.11.0'
 
 
 def FlattenList_detail(data):
@@ -148,7 +148,7 @@ Optionally the key to the item can be specified as a list. E.g.
         try:
             return functools.reduce(operator.getitem, key, data)
         except:
-            Error('"{0:s}" not in "{1:s}"'.format(key, filename))
+            Error('"{0:s}" not in "{1:s}"'.format('/'.join(key), filename))
 
     return data
 
@@ -328,8 +328,11 @@ Compute the checksums for ``filepaths``.
 
     test = np.in1d(source_paths, check_paths)
     idx = np.searchsorted(check_paths, source_paths)
+    idx = np.where(test, idx, 0)
     ret = np.where(test, check_sums[idx], None)
-    ret = list(ret[sorter])
+    out = np.empty_like(ret)
+    out[sorter] = ret
+    ret = list(out)
 
     if hybrid:
         for i in tqdm.trange(n, disable=not progress):
@@ -350,6 +353,7 @@ def ShelephantCopy(
     force = False,
     print_details = True,
     print_summary = True,
+    print_all = False,
     theme_name = 'none',
     yaml_hostinfo_src = None,
     yaml_hostinfo_dest = None):
@@ -387,6 +391,9 @@ Copy/move files.
     **print_summary** ([``True``] | ``False``)
         Print copy summary.
 
+    **print_all** ([``False``] | ``True``)
+        If ``False`` auto-truncation of long output is applied.
+
     **theme_name** ([``'none'``] | ``<str>``)
         The name of the color-theme. See ``Theme``.
 
@@ -396,6 +403,13 @@ Copy/move files.
         Specify these files *only* to use precomputed checksums.
     '''
 
+    assert type(files) == list
+
+    if len(files) == 0:
+        if not quiet:
+            print('Nothing to do')
+        return
+
     src = PrefixPaths(src_dir, files)
     dest = PrefixPaths(dest_dir, files)
     n = len(src)
@@ -429,8 +443,8 @@ Copy/move files.
     ncreate = sum(create)
     noverwrite = sum(overwrite)
     nskip = sum(skip)
-    pcreate = not (noverwrite > 0 and ncreate > 100)
-    pskip = nskip <= 100
+    pcreate = not ((noverwrite > 0 and ncreate > 100) or ncreate > 300) or print_all
+    pskip = (nskip <= 100) or print_all
     pcreate_message = ' (not printed)' if not pcreate else ''
     pskip_message = ' (not printed)' if not pskip else ''
 
@@ -485,11 +499,15 @@ Copy/move files.
         if not click.confirm('Proceed?'):
             return 1
 
-    pbar = tqdm.trange(n, disable=quiet, total=ncreate + noverwrite)
+    i = np.argwhere(np.not_equal(skip, True)).ravel()
+    src = np.array(src)[i]
+    dest = np.array(dest)[i]
+    files = np.array(files)[i]
+
+    pbar = tqdm.trange(len(files), disable=quiet)
     for i in pbar:
-        if not skip[i]:
-            pbar.set_description(files[i])
-            copy_function(src[i], dest[i])
+        pbar.set_description(files[i])
+        copy_function(src[i], dest[i])
 
 
 def ShelephantCopySSH(
@@ -503,6 +521,7 @@ def ShelephantCopySSH(
     force = False,
     print_details = True,
     print_summary = True,
+    print_all = False,
     verbose = False,
     theme_name = 'none',
     yaml_hostinfo_src = None,
@@ -544,6 +563,9 @@ Send/get files.
     **print_summary** ([``True``] | ``False``)
         Print copy summary.
 
+    **print_all** ([``False``] | ``True``)
+        If ``False`` auto-truncation of long output is applied.
+
     **verbose** ([``False``] | ``True``)
         Verbose all operations.
 
@@ -556,6 +578,13 @@ Send/get files.
         Specify these files *only* to use precomputed checksums.
     '''
 
+    assert type(files) == list
+
+    if len(files) == 0:
+        if not quiet:
+            print('Nothing to do')
+        return
+
     src = PrefixPaths(src_dir, files)
     dest = PrefixPaths(dest_dir, files)
     n = len(src)
@@ -594,8 +623,8 @@ Send/get files.
     ncreate = sum(create)
     noverwrite = sum(overwrite)
     nskip = sum(skip)
-    pcreate = not (noverwrite > 0 and ncreate > 100)
-    pskip = nskip <= 100
+    pcreate = not ((noverwrite > 0 and ncreate > 100) or ncreate > 300) or print_all
+    pskip = (nskip <= 100) or print_all
     pcreate_message = ' (not printed)' if not pcreate else ''
     pskip_message = ' (not printed)' if not pskip else ''
 
@@ -656,11 +685,15 @@ Send/get files.
         if not click.confirm('Proceed?'):
             return 1
 
-    pbar = tqdm.trange(n, disable=quiet, total=ncreate + noverwrite)
+    i = np.argwhere(np.not_equal(skip, True)).ravel()
+    src = np.array(src)[i]
+    dest = np.array(dest)[i]
+    files = np.array(files)[i]
+
+    pbar = tqdm.trange(len(files), disable=quiet)
     for i in pbar:
-        if not skip[i]:
-            pbar.set_description(files[i])
-            copy_function(host, src[i], dest[i], verbose)
+        pbar.set_description(files[i])
+        copy_function(host, src[i], dest[i], verbose)
 
 
 def Theme(theme=None):
