@@ -9,9 +9,14 @@ Usage:
     shelephant_extract [options] <input.yaml>
     shelephant_extract [options] <input.yaml> <key>...
 
+Arguments:
+    input.yaml      The file to read.
+    key             The keys to read from the file.
+
 Options:
     -o, --output=N  Output file. (default: <input.yaml>)
         --no-path   Do not interpret data as paths.
+    -s, --squash    Squash fields into a single field.
     -f, --force     Overwrite output file without prompt.
     -h, --help      Show help.
         --version   Show version.
@@ -25,9 +30,10 @@ import mergedeep
 import functools
 
 from .. import __version__
-from . import YamlGetItem
-from . import YamlDump
-from . import ChangeRootOfRelativePaths
+from .. import YamlGetItem
+from .. import YamlDump
+from .. import ChangeRootOfRelativePaths
+from .. import Squash
 
 
 def main():
@@ -52,6 +58,9 @@ def main():
         container = functools.reduce(lambda x, y: {y: x}, key[:-1], {key[-1]: files})
         mergedeep.merge(data, container)
 
+    if args['--squash']:
+        data = Squash(data)
+
     YamlDump(output, data, args['--force'])
 
 if __name__ == '__main__':
