@@ -4,6 +4,9 @@
 Usage:
     shelephant_parse <file.yaml>
 
+Argument:
+    File path.
+
 Options:
     -h, --help          Show help.
         --version       Show version.
@@ -14,8 +17,8 @@ Options:
 import docopt
 
 from .. import __version__
-from . import YamlRead
-from . import YamlPrint
+from .. import YamlRead
+from .. import YamlPrint
 
 
 def main():
